import axios from '@/utils/request'

// 查询藏品列表
export function listRelic(query) {
  return axios.get('/relic/list',{
    params: {
      ...query
    }
  })
}

// 查询全部藏品列表
export function listAllRelic(query) {
  return axios.get('/relic/listAll', {
    params: {
      ...query
    }
  })
}

// 查询藏品详细
export function getRelic(id) {
  return axios.get('/relic/info/' + id)
}

// 新增藏品
export function addRelic(data) {
  return axios.post('/relic/add', {
    ...data
  })
}

// 修改藏品
export function updateRelic(data) {
  return axios.put('/relic', data)
}

// 删除藏品
export function delRelic(id) {
  return axios.delete('/relic/' + id)
}
